==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/mi-NZ/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Mō Ngā Taonga',
    'about_assets_text'            => 'Ko nga taonga he taonga kua rapua e te tau rangatū, te tohu taonga ranei. He ahua nui ake o nga taonga kei te tautuhi i nga take e tika ana.',
    'archived'  				=> 'Whakamahia',
    'asset'  					=> 'Tahua',
    'bulk_checkout'             => 'Checkout Assets',
    'bulk_checkin'              => 'Checkin Assets',
    'checkin'  					=> 'Tirohia te Ahua',
    'checkout'  				=> 'Whakaritehia te Ahua',
    'clone'  					=> 'Te Tino Tae',
    'deployable'  				=> 'Kaore e taea',
    'deleted'  					=> 'This asset has been deleted.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Whakatikahia te Ahua',
    'model_deleted'  			=> 'This Assets model has been deleted. You must restore the model before you can restore the Asset.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Ka taea te tuku',
    'requested'				    => 'I tonohia',
    'not_requestable'           => 'Not Requestable',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Whakaorangia te Ahua',
    'pending'  					=> 'Kei te tatari',
    'undeployable'  			=> 'Kaore e taea',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Tirohia te Ahua',
    'csv_error' => 'You have an error in your CSV file:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Error messages:',
    'success_messages' => 'Success messages:',
    'alert_details' => 'Please see below for details.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mi-NZ/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Mō Ngā Taonga',
    'about_assets_text'            => 'Ko nga taonga he taonga kua rapua e te tau rangatū, te tohu taonga ranei. He ahua nui ake o nga taonga kei te tautuhi i nga take e tika ana.',
    'archived'  				=> 'Whakamahia',
    'asset'  					=> 'Tahua',
    'bulk_checkout'             => 'Putea Poaka',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Tirohia te Ahua',
    'checkout'  				=> 'Whakaritehia te Ahua',
    'clone'  					=> 'Te Tino Tae',
    'deployable'  				=> 'Kaore e taea',
    'deleted'  					=> 'This asset has been deleted.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'Whakatikahia te Ahua',
    'model_deleted'  			=> 'This Assets model has been deleted. You must restore the model before you can restore the Asset.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'Ka taea te tuku',
    'requested'				    => 'I tonohia',
    'not_requestable'           => 'Not Requestable',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'Whakaorangia te Ahua',
    'pending'  					=> 'Kei te tatari',
    'undeployable'  			=> 'Kaore e taea',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'Tirohia te Ahua',
    'csv_error' => 'You have an error in your CSV file:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'Error messages:',
    'success_messages' => 'Success messages:',
    'alert_details' => 'Please see below for details.',
    'custom_export' => 'Custom Export',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'User Department',
];
